<?php
/*
 * $Id
 */

require_once('include/prepend.php');
commonHeader("Copyright and License");

?>

<h1>Copyright and License</h1>


<h2>PHP License</h2>

<p>For information on the PHP License (i.e. using the PHP language),
    <?php print_link('http://www.php.net/license/', 'click here'); ?>.
    </p>

<h2>PHP-GTK License</h2>

<p>PHP-GTK is released under the LGPL.
    <?php print_link('http://www.gnu.org/copyleft/lesser.html#SEC1', 'Click here'); ?>
    for more info on the LGPL.</p>

<h2>Website Copyright</h2>

<p>The code, text, PHP logo, and graphical elements on this website and the
    mirror websites (the "Site") are Copyright &copy; 2001-<?php echo date('Y'); ?> The PHP
    Group.  All rights reserved.</p>

<p>Except as otherwise indicated elsewhere on this Site, you are free view,
    download and print the documents and information available on this Site
    subject to the following conditions:</p>

<ul>
    <li>You may not remove any copyright or other proprietary notices
        contained in the documents and information on this Site.</li>
    <li>The rights granted to you constitute a license and not a transfer of
        title.</li>
    <li>The rights specified above to view, download and print the documents
        and information available on this Site are not applicable to the
        graphical elements, design or layout of this Site.These elements of
        the Site are protected by trade dress and other laws and may not be
        copied or imitated in whole or in part.</li>
</ul>

<p>You can contact the webmaster at
    <?php print_email('php-gtk-webmaster@lists.php.net'); ?>.</p>

<p>For more information on the PHP Group and the PHP project, please see
    <?php print_link('http://www.php.net/'); ?>.</p>

<p>For more information on the PHP-GTK project, please see
    <?php print_link('http://gtk.php.net/'); ?>.</p>

<br />

<?php
commonFooter();

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim: expandtab sw=4 ts=4 fdm=marker
 */
?>
